/****************************************************************************
**
** Copyright (C) 1991-2008 Heinz van Saanen
**
** This file is part of the the function viewer Zhu3D.
**
** This file may be used under the terms of the GNU General Public
** License version 2 as published by the Free Software Foundation
** and appearing in the file LICENSE.GPL included in the packaging of
** this file.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
**
****************************************************************************/

#ifndef ANIEDITOR_H
#define ANIEDITOR_H

#include <QWidget>
#include <QCloseEvent>
#include <QSettings>
#include <QTimer>
#include "ui_aniedit.h"
#include "property.h"
#include "timers.h"
#include "version.h"
#include "debug.h"


// Handles animation
class aniWidget : public QWidget, private Ui::aniUI {

Q_OBJECT

public:
	aniWidget(QWidget *parent=0);
	~aniWidget() { timer->stop(); }

protected:
	void closeEvent(QCloseEvent *event);
	void changeEvent(QEvent* event);

public:
	void updAniWid();
	void animate(bool mode);
	float getClock();

private slots:
	void xSlot(int xVal);
	void ySlot(int yVal);
	void zSlot(int zVal);
	void aniXYZLocked() { ani.locXYZ = !ani.locXYZ; }

	void workSlot();				// The heavy worker-function
	void fpsSlot(int fps);
	void cpuSlot() { cpuDone=true; };

signals:
	void gotNewAni();				// Inform viewer to update OpenGL
	void updMaiWid();				// Update mainwindow
	void updMaiInf();				// Update info section of mainwindow
	void saveFromAni();				// Inform mainwindow to save current model
	void xRotationChanged(int x);	// Mouse-slider synchronisation in main
	void yRotationChanged(int y);
	void zRotationChanged(int z);

private:
	QTimer *timer;
	static const float offset=1.0f;
	int load;						// Current CPU/GPU utilization
	bool cpuDone;

	// Settings stuff
	void readSettings();
	void writeSettings();
	bool everStarted;
};

// ANIEDITOR_H
#endif
